==============================
semlix |release| documentation
==============================

semlix is based on Whoosh, which was created by `Matt Chaput <mailto:matt@whoosh.ca>`_.
semlix extends semlix with semantic search capabilities while maintaining full backward compatibility.

You can view the project and report issues on the
`semlix GitHub page <https://github.com/semlix/semlix>`_.


Contents
========

.. toctree::
    :maxdepth: 2

    releases/index
    quickstart
    intro
    glossary
    schema
    indexing
    searching
    semantic
    bm25
    unified
    migration
    parsing
    querylang
    dates
    query
    analysis
    stemming
    ngrams
    facets
    highlight
    keywords
    spelling
    fieldcaches
    batch
    threads
    nested
    recipes
    api/api
    tech/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

